@@ -1,6 +1,7 @@
 import click
 from bibtex_to_notion.funcs import txt_to_json, to_properties, make_request
 
+
 @click.command()
 @click.option("--bibtex", help="The person to greet.")
 def notion_bibtext(bibtex):
@@ -10,5 +11,5 @@ def notion_bibtext(bibtex):
     make_request(properties)
 
 
-if __name__ == '__main__':
-    notion_bibtext()
\ No newline at end of file
+if __name__ == "__main__":
+    notion_bibtext()
